library select_image;
import 'dart:io';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_exif_rotation/flutter_exif_rotation.dart';
import 'package:image_picker/image_picker.dart';

Future<File> chooseImage(BuildContext context) {
  return showModalBottomSheet(
      context: context,
      builder: (context) => const _ChooseImageDialog(),
      clipBehavior: Clip.antiAlias,
      shape: const RoundedRectangleBorder(
        borderRadius: BorderRadiusDirectional.only(
            topStart: Radius.circular(25), topEnd: Radius.circular(25)),
      )).then((value) {
    return value as File;
  });
}

class _ChooseImageDialog extends StatelessWidget {
  final String cameraText, galleryText, mainHintText;

  const _ChooseImageDialog(
      {Key? key,
      this.cameraText = "Camera",
      this.galleryText = "Gallery",
      this.mainHintText = "Choose Image From"})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.all(16),
      color: Colors.white,
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Text(
                mainHintText,
                style: const TextStyle(
                    color: Colors.black, fontWeight: FontWeight.bold),
              ),
              GestureDetector(
                  onTap: () {
                    Navigator.pop(context);
                  },
                  child: const Icon(Icons.close)),
            ],
          ),
          const SizedBox(
            height: 16,
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceAround,
            children: [
              _MyImageButton(
                icon: Icons.insert_photo,
                text: galleryText,
                source: ImageSource.gallery,
              ),
              _MyImageButton(
                icon: CupertinoIcons.photo_camera_solid,
                text: cameraText,
                source: ImageSource.camera,
              ),
            ],
          ),
        ],
      ),
    );
  }
}

class _MyImageButton extends StatelessWidget {
  final IconData? icon;
  final String? text;
  final ImageSource? source;

  const _MyImageButton(
      {Key? key, this.icon, required this.text, required this.source})
      : super(key: key);

  Future<File> getImage(BuildContext context, ImageSource source) async {
    final picker = ImagePicker();
    final pickedFile = await picker.pickImage(source: source);
    if (pickedFile != null) {
      final image =
          await FlutterExifRotation.rotateImage(path: pickedFile.path);
      return image;
    }
    return null!;
  }

  @override
  Widget build(BuildContext context) {
    return CupertinoButton(
      child: Row(
        children: [
          Icon(icon, color: Theme.of(context).primaryColor),
          const SizedBox(
            width: 10,
          ),
          Text(
            text!,
            style: const TextStyle(
              fontWeight: FontWeight.normal,
              color: Colors.black,
            ),
          ),
        ],
      ),
      onPressed: () {
        var image = getImage(context, source!);
        Navigator.pop(context, image);
      },
    );
  }
}
